==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/bg.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управление на Lightbox Gallary Параметри");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Управление на галерия");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "В пълен размер Ширина на изображението");
define('MANAGE_GALLERY_FULL_HEIGHT', "Изображението в пълен размер Височина");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Ширина на изображението");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Височина на изображението");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Съхрани Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Показване на дялове");
define('MANAGE_GALLERY_DISABLE_SORT', "Изключване на сортиране");
define('MANAGE_GALLERY_DELETE_IMAGE', "Изтриване на снимката");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Запазване на реда на сортиране");
define('MANAGE_GALLERY_PUBLISH_MSG', "Кликнете върху &#39;Актуализация &quot;да публикува <br /> качените изображения.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Всички изображения са преоразмерени и настройки са запазени.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Имаше грешка при преоразмеряване на изображенията или запазването на настройките.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Вашето изображение (я) е качен.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Имаше грешка при качването на изображението (и).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файлът, който се опитвате да качите не е изображение.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файлът, който се опитвате да качите е твърде голям.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Заглавието е запазена.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Сигурни ли сте, че искате да изтриете изображение");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Изображението е била изтрита.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Имаше грешка при изтриване на изображението.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Запазване на параметрите и преоразмеряване на изображенията, моля изчакайте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Качва се, моля изчакайте ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Редът на подреждане не е запазена. Искате ли да запазите реда на сортиране?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Заповедта за изображение на сортиране е запазена.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "При запазването на вида на изображението грешка.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/bg.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управление на Lightbox Gallary Параметри");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Управление на галерия");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "В пълен размер Ширина на изображението");
define('MANAGE_GALLERY_FULL_HEIGHT', "Изображението в пълен размер Височина");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Ширина на изображението");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Височина на изображението");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Съхрани Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Показване на дялове");
define('MANAGE_GALLERY_DISABLE_SORT', "Изключване на сортиране");
define('MANAGE_GALLERY_DELETE_IMAGE', "Изтриване на снимката");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Запазване на реда на сортиране");
define('MANAGE_GALLERY_PUBLISH_MSG', "Кликнете върху &#39;Актуализация &quot;да публикува <br /> качените изображения.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Всички изображения са преоразмерени и настройки са запазени.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Имаше грешка при преоразмеряване на изображенията или запазването на настройките.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Вашето изображение (я) е качен.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Имаше грешка при качването на изображението (и).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файлът, който се опитвате да качите не е изображение.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файлът, който се опитвате да качите е твърде голям.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Заглавието е запазена.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Сигурни ли сте, че искате да изтриете изображение");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Изображението е била изтрита.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Имаше грешка при изтриване на изображението.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Запазване на параметрите и преоразмеряване на изображенията, моля изчакайте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Качва се, моля изчакайте ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Редът на подреждане не е запазена. Искате ли да запазите реда на сортиране?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Заповедта за изображение на сортиране е запазена.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "При запазването на вида на изображението грешка.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Файлът, който се опитвате да качите, е по-голям от настройките на PHP „upload_max_filesize“ или от „post_max_size“. Свържете се със системния си администратор, за да увеличите тези ограничения.");
?>
